Users Documents
===============
If you take the data files (e. g. tiff files, edf files, txt files) from the beamline and plan to process the
data, here is the tutorial for you.


.. toctree::
   :maxdepth: 1

   calibration
   average
   integration
   transformation
